/************************************************************************/
/*                                                                      */
/*  AMD Embedded Flash Memory Card Evaluation Kit                       */
/*  File name: EMBED.H                                                  */
/*  Revision:  1.7Beta 9/25/96                                          */
/*                                                                      */
/* Copyright (c) 1995 ADVANCED MICRO DEVICES, INC. All Rights Reserved. */
/* This software is unpublished and contains the trade secrets and      */
/* confidential proprietary information of AMD. Unless otherwise        */
/* provided in the Software Agreement associated herewith, it is        */
/* licensed in confidence "AS IS" and is not to be reproduced in whole  */
/* or part by any means except for backup. Use, duplication, or         */
/* disclosure by the Government is subject to the restrictions in       */
/* paragraph (b) (3) (B) of the Rights in Technical Data and Computer   */
/* Software clause in DFAR 52.227-7013 (a) (Oct 1988).                  */
/* Software owned by                                                    */
/* Advanced Micro Devices, Inc.,                                        */
/* One AMD Place,                                                       */
/* P.O. Box 3453                                                        */
/* Sunnyvale, CA 94088-3453.                                            */
/*                                                                      */
/*                                                                      */
/* Revision History:    1.1     Original                                */
/*                      1.6Beta Added support for F016 chip cards       */
/*                      1.7Beta Added support for Miniature Cards       */
/************************************************************************/


/************************************************************************/
/*      Defined variables for emb_erase, emb_prog()                    */
/*                                                                 */
/*******************************************************************/
#define FL_28F          1               /* Select 28F devices */
#define FL_29F          2               /* Select 29F devices */

#define FL_PROG         0               /* Select Programming op. */
#define FL_CH_ERASE 1           /* Select Chip Erase op. */
#define FL_SC_ERASE 2           /* Select Sector Erase op. */

#define RESET                           0xf0
#define AUTOSELECT              0x90
#define WRITE                           0xa0
#define SEGMENT_ERASE   0x10
#define SECTOR_ERASE            0x30
#define SECTOR_ERASE_SUSPEND            0xB0
#define SECTOR_ERASE_RESUME             0x33

#define TRUE            1
#define FALSE           0

#define BIN             1
#define HEX             2
#define SINGLE          3               //single byte program  
#define WORD            4               /* word program          */
#define FILE_INPUT              5
#define CM_READ 6
#define CM_WRITE  2
#define AM_READ   7
#define AM_WRITE  3

#define CARDSTART_DI    0

/* ****************************************************************** *
 *                                                      STRUCTURES                                *
 * ****************************************************************** */
/******  xxxx_GS = variable is a or part of a global structure *****/
/******  xxxx_GA = variable is a global array                  *****/
typedef struct dev {
	int device_no_GS;
	char *devname_GS;
	int num_sectors;
	unsigned long kb_size_GS;
	unsigned long sector_size;
	unsigned int device_id_GS;
	unsigned char manuf_id_GS;
} devices_GS;

#define INVALID         0
#define AMC001CFLKA     1
#define AMC002CFLKA     2
#define AMC004CFLKA     3
#define AMC010CFLKA     4
#define AMC004DFLKA     5
#define AMC008DFLKA     6
#define AMC020DFLKA     7
#define FUC032DFLKA_O   8
#define FUC032DFLKA_N   9
#define AMC064DFLKA     10

/*
#define FUC008DFLKA     8
#define FUC032DFLKA     9
*/
#define Am29F040                8
#define Am29F016                9
#define AM4MBF016       11
#define AmMC002A        12
#define AmMC004A        13
#define AmMC008A        14
#define AmMCL002A       15      /* LV008 devices */
#define AmMCL004A       16      /* LV008 devices */


#define MAX_NUM_SECTORS 11

devices_GS amd_devices_GA[] =
{
	INVALID,   "INVALID",  0,  00000000L, 000000L, 0x00, 0x00,
	AMC001CFLKA,  "AMC001CFLKA",   16,   1048576L, 131072L, 0xA4A4, 0x0101,
	AMC002CFLKA,  "AMC002CFLKA",   32,   2097152L, 131072L, 0xA4A4, 0x0101,
	AMC004CFLKA,  "AMC004CFLKA",   64,   4194304L, 131072L, 0xA4A4, 0x0101,
	AMC010CFLKA,  "AMC010CFLKA",  160,  10485760L, 131072L, 0xA4A4, 0x0101,
	AMC004DFLKA,  "AMC004DFLKA",   64,   4194304L, 131072L, 0x3D3D, 0x0101,
	AMC008DFLKA,  "AMC008DFLKA",  128,   8388608L, 131072L, 0x3D3D, 0x0101,
	AMC020DFLKA,  "AMC020DFLKA",  320,  20971520L, 131072L, 0x3D3D, 0x0101,
	FUC032DFLKA_O,  "FUC032DFLKA",  512,  33554432L, 131072L, 0xADAD, 0x0404,
	FUC032DFLKA_N,  "FUC032DFLKA",  512,  33554432L, 131072L, 0x3D3D, 0x0404,
	AMC064DFLKA,  "AMC064DFLKA",  1024,  67108864L, 131072L, 0x3D3D, 0x0101,
	AM4MBF016,    "AM4MBF016",      512,  33554432L, 131072L, 0xADAD, 0x0101,
	AmMC002A,       "AmMC002A",     32,   2097152L, 131072L, 0xD5D5, 0x0101,
	AmMC004A,       "AmMC004A",     64,   4194304L, 131072L, 0x3D3D, 0x0101,
	AmMC008A,       "AmMC008A",     128,  8388608L, 131072L, 0x3D3D, 0x0101,
	AmMCL002A,      "AmMCL002A",    32,   2097152L, 131072L, 0x3838, 0x0101,
	AmMCL004A,      "AmMCL004A",    64,   4194304L, 131072L, 0x3838, 0x0101
};

/* ****************************************************************** *
 *                                                      FORWARD DECLARATIONS                            *
 * ****************************************************************** */
int  program_word();
int  program_cm_file();
int  sector_erase();
int  card_erase();
void autoselect_seq();
void cmd_seq(int);
void cmd_seq_byte(int);
int  dq7_poll();
int  sel_device(void);
int  erase_suspend(int);
void error_handler(int);
int  write_bin(void);
int  address_check();

/* ****************************************************************** *
 *                                                      GLOBALS                                   *
 * ****************************************************************** */
unsigned long system_base_address      = 0xd0000000;            
unsigned long system_address                    = 0xd0000000;           
unsigned long int  window_size                  = 0x10000;
unsigned long int cardaddress              = 0;         
unsigned long int numbytes                 = 0;         
unsigned long int input_address         = 0;            
unsigned long int max_cardaddress               = 0;            
unsigned long int min_cardaddress               = 0;            
unsigned long int cardoffset                            = 0;            
unsigned long int max_addr_L                            = 0;            
unsigned int  cardoffset_DI                             = 0;
long oldcount, newcount;
int odd_offset;
unsigned char far *in_data_L;
unsigned char far *in_data_L_B;
unsigned int far *in_data_L_W;
unsigned char far in_data;
unsigned char far in_data_byte;
unsigned int far in_data_word;
unsigned int write_data;
unsigned char write_data_B;
unsigned int current_data_G;
unsigned char filename[81];

unsigned                long address_G    = 0L;         /* address is larger than 16 bits       */
devices_GS      *this_dev_GSP           = NULL; /* pointer to the current device        */
unsigned int    curr_data_G=0;   /* current data to be programmed       */
unsigned int    m_code_G;       /* temp storage for manuf code          */
unsigned int    d_code_G;               /* temp storage for device code         */
int                             errdata_G       = 0;   /* on error, the current byte data is placed here */
int                             flerror_code_G  = 0;    /* Error Code from subroutines          */
char                            string_GA[32], string2_GA[4];  /* Strings used for int to ASCII conversion      */

int                             no_device_G     = 1;     /* If no device was found, no_device_G=1 */

/********************************************************************/
/* Defines for Error_handler()                                      */
/********************************************************************/
#define NO_FILE_NAME_ENTERED    10
#define INPUT_FILENAME_MISSING  11
#define FILENAME_PROBLEM                12
#define BAD_RECORD_CODE_1               19
#define DATACOUNT_ERROR_1               20
#define PROGRAMMING_FAILURE             39
#define DQ7_PROGRAM_FAILURE             46
#define DQ7_FAIL_AFTER_DQ5_1    47
#define DQ7_FAIL_AFTER_DQ5_2    48
#define DQ7_ERASE_FAILURE               49
#define DQ7_ERASE_FAILURE_DQ5   50
#define DQ7_ERASE_ON_28F                51
#define DQ7_ERASE_ON_29F                52
#define ADDRESS_EXCEEDS_LIMITS  53
#define UNKNOWN_BREAK_READHEX   54
#define DEVICE_IS_NOT_AMD_1             59
#define DEVICE_IS_NOT_AMD_2             60
#define SELECT_DEVICE_FIRST             61
#define DEVICE_SIZE_EXCEEDED    62
#define DQ5_ON_NO_POLL                  63
#define NOT_FOR_THIS_DEVICE     70
#define ERASE_SUSPEND_NOT_SUPP  80
#define DEVICE_IS_NOT_CORRECT           82
#define LOCATION_NOT_ERASED             83
/* Assembly function arguments */

/* set_page */
unsigned short int memctrl;

/* set_window */
int window_base;
int window_dx;
unsigned short int window_dh;
unsigned short int window_dl;


